Method: Germinate.path
- Defined in:
- lib/germinate.rb
.path(*args) ⇒ Object
Returns the lpath for the module. If any arguments are given, they will be joined to the end of the path using File.join.
31 32 33 |
# File 'lib/germinate.rb', line 31 def self.path( *args ) args.empty? ? PATH : ::File.join(PATH, args.flatten) end |